@@ -58,12 +58,13 @@ class Cleanup:
         Description:
             1. Suppress initial comments.
             2. Suppress `if __name__ == '__main__'` part.
-            3. Replace tabulations with spaces.
-            4. Normalize Paroxython hint comments.
-            5. Replace docstrings with `pass` statements (most of which being suppressed at the end
+            3. Suppress `sys.path` injections (frequently used to simplify `import` behavior).
+            4. Replace tabulations with spaces.
+            5. Normalize Paroxython hint comments.
+            6. Replace docstrings with `pass` statements (most of which being suppressed at the end
                of the process).
-            6. Suppress empty or blank lines.
-            7. Suppress useless `pass` statements.
+            7. Suppress empty or blank lines.
+            8. Suppress useless `pass` statements.
 
         Examples:
             - Empty or blank lines are suppressed.
@@ -234,6 +235,14 @@ class Cleanup:
             ```python
             foo = bar
             ```
+            - `sys.path` injections are suppressed.
+            ```python
+            __import__("sys").path[0:0] = ["programs"]
+            (28433 * 2**7830457 + 1) % 10**10
+            ```
+            ```python
+            (28433 * 2**7830457 + 1) % 10**10
+            ```
 
             All examples above automatically extracted from
             [test_cleanup_source.py](https://repo/tests/test_cleanup_source.py).
@@ -248,6 +257,7 @@ class Cleanup:
         text = str(source)
         text = Cleanup.suppress_first_comments(text)
         text = Cleanup.suppress_main_guard(text)
+        text = Cleanup.suppress_sys_path_injection(text)
         text = text.replace("\t", "    ")
         lines = iter(text.split("\n"))
         for token_info in generate_tokens(lambda: next(lines) + "\n"):
@@ -294,6 +304,17 @@ class Cleanup:
         """
         return sub("", source)
 
+    @staticmethod
+    def suppress_sys_path_injection(
+        source: str,
+        sub: Callable = regex.compile(r'(?m)^__import__\("sys"\)\.path\[0:0\] = .+\n').sub,
+    ) -> str:
+        """Suppress lines starting with `__import__("sys").path[0:0] = `.
+
+        Argument `sub` [not to be explicitly provided.](developer_manual/index.html#default-argument-trick)
+        """
+        return sub("", source)
+
     @staticmethod
     def normalize_paroxython_comments(
         source: str,
